/**
 * @file libertine_store/i18n.h
 * @brief Internationalization helpers.
 */
/*
 * Copyright 2016 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, version 3, as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef LIBERTINE_STORE_I18N_H_
#define LIBERTINE_STORE_I18N_H_

#include <libintl.h>
#include <string>


/**
 * Translates a simple string.
 * @param[in] msgid The string to be translated.
 * @returns the translated string.
 */
inline std::string
_(char const* msgid)
{
  return dgettext(GETTEXT_PACKAGE, msgid);
}


/**
 * Translates a single/plural string pair.
 * @param[in] msgid1 The string to be tranlated (single form).
 * @param[in] msgid2 The string to be translated (plural form).
 * @param[in] n      The number of items referenced in the string.
 *
 * @returns the translated string, either singular or plural forms depending on
 * @p n.
 */
inline std::string
_(char const* msgid1, char const* msgid2, unsigned long int n)
{
  char buffer [256];
  if (snprintf(buffer, 256, dngettext(GETTEXT_PACKAGE, msgid1, msgid2, n), n ) >= 0)
  {
    return buffer;
  }
  else
  {
    return std::string();
  }
}

#endif /* LIBERTINE_STORE_I18N_H_ */
