/*
 * Copyright 2016 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, version 3, as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#pragma once

#include <unity/scopes/PreviewQueryBase.h>
#include <unity/scopes/PreviewWidget.h>


namespace libertine
{
namespace scope
{


class ServiceManager;
class Package;


class Preview
: public unity::scopes::PreviewQueryBase
{
public:
  explicit Preview(unity::scopes::Result const&           result,
                   unity::scopes::ActionMetadata const&   metadata,
                   std::shared_ptr<ServiceManager> const& service);

  virtual ~Preview() = default;

  virtual void
  cancelled() override;

  virtual void
  run(unity::scopes::PreviewReplyProxy const& reply) override;

protected:
  virtual unity::scopes::PreviewWidget
  buttonWidgets(libertine::scope::Package const& package) const;

private:
  unity::scopes::PreviewWidgetList
  createWidgets(libertine::scope::Package const& app) const;

  unity::scopes::PreviewWidgetList
  headerWidgets(libertine::scope::Package const& app) const;

  unity::scopes::PreviewWidget
  descriptionWidgets(libertine::scope::Package const& app) const;

  void
  registerLayouts(unity::scopes::PreviewReplyProxy const& reply);

  void
  createSingleColumnLayout(Package const& app);

  void
  createDualColumnLayout(Package const& app);

  struct {
    std::vector<std::string> column;
  } oneColumn;

  struct {
    std::vector<std::string> column1;
    std::vector<std::string> column2;
  } twoColumns;

  std::shared_ptr<ServiceManager> service_;
};
} // namespace scope
} // namespace libertine
