/*
 * Copyright 2016 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, version 3, as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "scope/apps/preview.h"

#include "scope/apps/config.h"
#include "scope/apps/hidden_apps.h"
#include <libertine-scope/i18n.h>
#include <unity/scopes/PreviewReply.h>
#include <unity/scopes/Variant.h>
#include <unity/scopes/VariantBuilder.h>
#include <unity/scopes/ActionMetadata.h>
#include <unity/scopes/Result.h>

namespace usc = unity::scopes;


Preview::
Preview(usc::Result const&                                result,
        usc::ActionMetadata const&                        metadata,
        std::shared_ptr<libertine::scope::ServiceManager> service,
        std::shared_ptr<HiddenApps>                       hidden)
  : libertine::scope::Preview(result, metadata, service)
  , hidden_(hidden)
{
}


unity::scopes::PreviewWidget Preview::buttonWidgets(libertine::scope::Package const&) const
{
  usc::PreviewWidget buttons("actions", "actions");
  usc::VariantBuilder vb;
  vb.add_tuple({
    {"id",    usc::Variant("open")},
    {"label", usc::Variant(_("Open"))}
  });

  if (hidden_->app_is_hidden(QString::fromStdString(result()["app_id"].get_string())))
  {
    vb.add_tuple({
                   {"id",    usc::Variant("show")},
                   //Translators: Users tap "Show" button to remove an app from the hidden list of apps: so the meaning is to undo a hide
                   {"label", usc::Variant(_("Show"))},
                 });
  }
  else
  {
    vb.add_tuple({
                   {"id",    usc::Variant("hide")},
                   {"label", usc::Variant(_("Hide"))},
                 });
  }
  buttons.add_attribute_value("actions", vb.end());
  return buttons;
}
