/*
 * Copyright 2016 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, version 3, as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef LIBERTINE_STORE_QUERY_H_
#define LIBERTINE_STORE_QUERY_H_


#include <unity/scopes/ReplyProxyFwd.h>
#include <unity/scopes/SearchQueryBase.h>

class QStringList;


namespace libertine
{
namespace scope
{

class ServiceManager;

/**
 * Engine to run a specific store query.
 */
class Query
    : public unity::scopes::SearchQueryBase
{
public:
  explicit Query(unity::scopes::CannedQuery      const&    query,
                 unity::scopes::SearchMetadata   const& metadata,
                 std::shared_ptr<ServiceManager> const& service);

  ~Query() = default;

  virtual void
  cancelled() override;

  virtual void
  run(unity::scopes::SearchReplyProxy const& reply) override;

  static std::string const USE_SEARCH_HINT;
  static std::string const NO_SEARCH_RESULTS_HINT;

private:
  void
  show_hint(unity::scopes::SearchReplyProxy const& reply,
            std::string const&                     reason) const;
  void
  run_search(unity::scopes::SearchReplyProxy const& reply) const;

  std::shared_ptr<ServiceManager> service_;
};

} // namespace scope
} // namespace libertine

#endif // LIBERTINE_STORE_QUERY_H_


