/**
 * @file libertine_store/scope.cpp
 * @brief The implementation of the Libertine Store scope class.
 */
/*
 * Copyright 2016 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, version 3, as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "scope/store/scope.h"

#include "scope/store/query.h"
#include <libertine-scope/action.h>
#include <libertine-scope/i18n.h>
#include <libertine-scope/preview.h>
#include <libertine-scope/service_manager.h>


namespace usc = unity::scopes;



libertine::scope::Scope::
Scope()
  : service_(std::make_shared<ServiceManager>())
{ }


void libertine::scope::Scope::
start(std::string const&)
{
  setlocale(LC_ALL, "");
  std::string translation_directory = ScopeBase::scope_directory()
                                    + "/../share/locale/";
  bindtextdomain(GETTEXT_PACKAGE, translation_directory.c_str());
}


usc::SearchQueryBase::UPtr libertine::scope::Scope::
search(usc::CannedQuery const&    query,
       usc::SearchMetadata const& metadata)
{
  return usc::SearchQueryBase::UPtr(new Query(query, metadata, service_));
}


usc::PreviewQueryBase::UPtr libertine::scope::Scope::
preview(usc::Result const&         result,
        usc::ActionMetadata const& metadata)
{
  return usc::PreviewQueryBase::UPtr(new Preview(result, metadata, service_));
}



usc::ActivationQueryBase::UPtr libertine::scope::Scope::
perform_action(usc::Result const&         result,
               usc::ActionMetadata const& metadata,
               std::string const&         /* widget_id */,
               std::string const&         action_id)
{
  return usc::ActivationQueryBase::UPtr(new Action(result,
                                                   metadata,
                                                   action_id,
                                                   service_));
}

