/**
 * @file libertine_store/scope.h
 * @brief The internal interface for the Libertine Store scope class.
 */
/*
 * Copyright 2016 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, version 3, as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef LIBERTINE_STORE_SCOPE_H_
#define LIBERTINE_STORE_SCOPE_H_

#include <unity/scopes/ScopeBase.h>

namespace libertine
{
namespace scope
{

class ServiceManager;


class Scope
: public unity::scopes::ScopeBase
{
public:
  explicit Scope();
  virtual ~Scope() = default;

  /**
   * Initializes the scope instance.
   */
  virtual void
  start(std::string const&) override;

  /**
   * Called each time a new query is requested
   */
  virtual unity::scopes::SearchQueryBase::UPtr
  search(unity::scopes::CannedQuery const&    query,
         unity::scopes::SearchMetadata const& metadata) override;

  /**
   * Gets an application preview.
   */
  virtual unity::scopes::PreviewQueryBase::UPtr
  preview(unity::scopes::Result const&         result,
          unity::scopes::ActionMetadata const& metadata) override;

  /**
   * Gets an application preview.
   */
  virtual unity::scopes::ActivationQueryBase::UPtr
  perform_action(unity::scopes::Result const&         result,
                 unity::scopes::ActionMetadata const& metadata,
                 std::string const&                   widget_id,
                 std::string const&                   action_id) override;

private:
  std::shared_ptr<ServiceManager> service_;
};


} // namespace scope
} // namespace libertine

#endif /* LIBERTINE_STORE_SCOPE_H_ */



