/*
 * Copyright 2016 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, version 3, as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "libertine-scope/action.h"

#include "tests/lib/libertine-scope/mock_service_manager.h"
#include <unity/scopes/ActionMetadata.h>
#include <unity/scopes/testing/Result.h>
#include <gmock/gmock.h>


namespace
{
TEST(StoreActionTest, CallsInstallOnServiceManager)
{
  unity::scopes::testing::Result result;
  result["id"] = "vim-common";
  unity::scopes::ActionMetadata metadata("en_US", "phone");
  auto service = std::make_shared<testing::NiceMock<libertine::scope::MockServiceManager> >();

  libertine::scope::Action action(result, metadata, "install", service);

  EXPECT_CALL(*service, install(QString("vim-common")));

  auto response = action.activate();
  EXPECT_EQ(unity::scopes::ActivationResponse::Status::ShowPreview, response.status());
}


TEST(StoreActionTest, CallsRemoveOnServiceManager)
{
  unity::scopes::testing::Result result;
  result["id"] = "gedit";
  unity::scopes::ActionMetadata metadata("en_US", "phone");
  auto service = std::make_shared<testing::NiceMock<libertine::scope::MockServiceManager> >();

  libertine::scope::Action action(result, metadata, "remove", service);

  EXPECT_CALL(*service, remove(QString("gedit")));

  auto response = action.activate();
  EXPECT_EQ(unity::scopes::ActivationResponse::Status::ShowPreview, response.status());
}


TEST(StoreActionTest, OpenAllowsDefaultHandlerToRun)
{
  unity::scopes::testing::Result result;
  result["id"] = "gedit";
  unity::scopes::ActionMetadata metadata("en_US", "phone");
  auto service = std::make_shared<testing::NiceMock<libertine::scope::MockServiceManager> >();

  libertine::scope::Action action(result, metadata, "open", service);

  auto response = action.activate();
  EXPECT_EQ(unity::scopes::ActivationResponse::Status::NotHandled, response.status());
}
}
