/*
 * Copyright 2016 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, version 3, as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "libertine-scope/package.h"

#include <gmock/gmock.h>


namespace
{
using namespace libertine::scope;


static QVariantMap
attribute_map(QString const& name, QString const& summary, QString const& description,
              QString const& icon, QString const& publisher, QString const& website,
              QString const& license, QString const& id, QString const& pkgname,
              QString const& status, QStringList screenshots)
{
  QVariantMap attributes;
  attributes["name"] = name;
  attributes["summary"] = summary;
  attributes["description"] = description;
  attributes["icon"] = icon;
  attributes["publisher"] = publisher;
  attributes["website"] = website;
  attributes["license"] = license;
  attributes["id"] = id;
  attributes["package"] = pkgname;
  attributes["status"] = status;
  attributes["screenshots"] = screenshots;
  return attributes;
}


static void
package_matches_attributes(Package actual, std::string const& name, std::string const& summary,
                           std::string const& description, std::string const& icon, std::string const& publisher,
                           std::string const& website, std::string const& license, std::string const& id,
                           std::string const& pkgname, std::string const& status, QStringList screenshots)
{
  EXPECT_EQ(name, actual.name);
  EXPECT_EQ(summary, actual.summary);
  EXPECT_EQ(description, actual.description);
  EXPECT_EQ(icon, actual.icon);
  EXPECT_EQ(publisher, actual.publisher);
  EXPECT_EQ(website, actual.website);
  EXPECT_EQ(license, actual.license);
  EXPECT_EQ(id, actual.id);
  EXPECT_EQ(pkgname, actual.package);
  EXPECT_EQ(status, actual.status);

  ASSERT_EQ(actual.screenshots.size(), screenshots.size());
  for (auto i = 0u; i < actual.screenshots.size(); ++i)
  {
    EXPECT_EQ(screenshots[i], QString::fromStdString(actual.screenshots[i]));
  }
}


TEST(PackageTest, FromMapCreatesSinglePackage)
{
  QStringList screenshots{"file:///some/image.png", "file:///some/other/image.jpg"};
  auto attributeMap = attribute_map("Harry", "The Philosopher's Stone",
                                    "Boy with head injury seeks magic rock",
                                    "harry.png", "JK", "pottermore.com", "Private",
                                    "com.pottermore.harry", "harry", "finished", screenshots);
  auto package = Package::from_map(attributeMap);
  package_matches_attributes(package, "Harry", "The Philosopher's Stone",
                             "Boy with head injury seeks magic rock",
                             "harry.png", "JK", "pottermore.com", "Private",
                             "com.pottermore.harry", "harry", "finished", screenshots);
}


TEST(PackageTest, FromMapCreatesListOfPackages)
{
  QStringList screenshots{"file:///some/image.png", "file:///some/other/image.jpg"};
  auto attributePkg1Map = attribute_map("Harry", "The Philosopher's Stone",
                                    "Boy with head injury seeks magic rock",
                                    "harry.png", "JK", "pottermore.com", "Private",
                                    "com.pottermore.harry", "harry", "finished", screenshots);
  QStringList screenshots2{"file://imageFor2.png"};
  auto attributePkg2Map = attribute_map("Dune", "Classic science fiction",
                                    "The spice must flow", "worms.png",
                                    "Herbert", "dunebook.net", "Other",
                                    "net.dunebook.dune", "dune", "spicey", screenshots2);
  auto packages = Package::from_map(QList<QVariantMap>{attributePkg1Map, attributePkg2Map});
  ASSERT_EQ(2, packages.size());
  package_matches_attributes(packages[0], "Harry", "The Philosopher's Stone",
                             "Boy with head injury seeks magic rock",
                             "harry.png", "JK", "pottermore.com", "Private",
                             "com.pottermore.harry", "harry", "finished", screenshots);
  package_matches_attributes(packages[1], "Dune", "Classic science fiction",
                             "The spice must flow", "worms.png",
                             "Herbert", "dunebook.net", "Other",
                             "net.dunebook.dune", "dune", "spicey", screenshots2);
}
}
